@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: network.cpp,v 1.18 2005/03/27 17:43:26 cepek Exp $
+ *  $Id: network.cpp,v 1.20 2005/05/07 18:06:19 cepek Exp $
  */
 
 #include <fstream>
@@ -779,7 +779,7 @@ void LocalNetwork::vyrovnani_()
   if (sum_points()      == 0)
     throw GaMaLib::Exception(T_GaMa_No_points_available);
 
-  BaseOLS<Double, GaMaLib::MatVecException>::solve();
+  GNU_gama::AdjBase<Double, GaMaLib::MatVecException>::solve();
 
   tst_vyrovnani_ = true;
 
@@ -830,7 +830,7 @@ void LocalNetwork::vyrovnani_()
   }
 
   { /* ----------------------------------------------------------------- */
-    r = BaseOLS<Double, GaMaLib::MatVecException>::residuals();
+    r = GNU_gama::AdjBase<Double, GaMaLib::MatVecException>::residuals();
     suma_pvv_ = 0;
 
     Double tmp;
