@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- * $Id: gama-g3.cpp,v 1.12 2004/03/24 19:27:06 cepek Exp $
+ * $Id: gama-g3.cpp,v 1.14 2005/05/07 18:06:20 cepek Exp $
  */
 
 #include <fstream>
@@ -168,6 +168,23 @@ int main_g3()
                << "  val = "
                << d->obs();
           
+          if (d->from_dh || d->to_dh)
+            {
+              cerr << " ( ";
+              cerr << d->from_dh << " ";
+              cerr << d->to_dh << " ";
+              cerr << ")";
+            }              
+        }
+      if (ZenithAngle *d = dynamic_cast<ZenithAngle*>(*i))
+        {
+          cerr << " zenith   : from = "
+               << d->from
+               << "  to = "
+               << d->to
+               << "  val = "
+               << d->obs();
+          
           if (d->from_dh || d->to_dh)
             {
               cerr << " ( ";
