@@ -1,6 +1,6 @@
 /*  
     GNU Gama C++ library
-    Copyright (C) 1999, 2002, 2003  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 1999, 2002, 2003  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
     
@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: gama-local-main.h,v 1.20 2004/11/02 18:15:54 cepek Exp $
+ *  $Id: gama-local-main.h,v 1.26 2005/06/04 21:06:43 cepek Exp $
  */
 
 #ifndef GAMA_MAIN__gama_main__gm_mn__g_m__g______________________________h___
@@ -36,6 +36,7 @@
 #include <gamalib/xml/gkfparser.h>
 #include <gamalib/local/network_svd.h>
 #include <gamalib/local/network_gso.h>
+#include <gamalib/local/network_chol.h>
 #include <gamalib/local/acord.h>
 
 #include <gamalib/xml/adjusted/coordinates.h>
@@ -79,7 +80,7 @@ int help()
        << " [ output. ]\n\n";
   cerr << "Options:\n"
        << "\n";
-  cerr << "--algorithm  svd | gso\n" 
+  cerr << "--algorithm  svd | gso | cholesky\n" 
        << "--language   en | ca | cz | du | fi | hu\n"
        << "--encoding   utf-8 | iso-8859-2 | iso-8859-2-flat | cp-1250\n"
        << "--angles     400 | 360\n"  
@@ -204,8 +205,9 @@ int GaMa_Main(int argc, char **argv)
           IS = new LocalNetwork_svd;        // implicit algorithm
         }
       else {
-        if (     !strcmp("svd", argv_algo)) IS = new LocalNetwork_svd;
-        else if (!strcmp("gso", argv_algo)) IS = new LocalNetwork_gso;
+        if (     !strcmp("svd",      argv_algo)) IS = new LocalNetwork_svd;
+        else if (!strcmp("gso",      argv_algo)) IS = new LocalNetwork_gso;
+        else if (!strcmp("cholesky", argv_algo)) IS = new LocalNetwork_chol;
         else return help();
       }
 
@@ -497,10 +499,14 @@ int GaMa_Main(int argc, char **argv)
       cout << "\n" << T_GaMa_solution_ended_with_error << "\n\n"
            << "****** " << V.text << "\n\n";
     }
+  catch(const GNU_gama::Exception::adjustment& choldec)
+    {
+      cout << "\n" << T_GaMa_solution_ended_with_error << "\n\n"
+           << "****** " << choldec.str << "\n\n";
+    }
   catch(...)
     {
       cout << "\n" << T_GaMa_internal_program_error << "\n\n";
-      throw;
     }
   
   return 1;
