@@ -1,6 +1,6 @@
 /*  
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
-    Copyright (C) 2002  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 2002  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU GaMa / GaMaLib C++ Library.
     
@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: adj.cpp,v 1.4 2005/03/27 17:43:26 cepek Exp $
+ *  $Id: adj.cpp,v 1.9 2005/06/04 21:02:04 cepek Exp $
  */
 
 #include <gnu_gama/adj/adj.h>
@@ -200,8 +200,8 @@ void AdjInputData::read_gama_local_old_format(std::istream& inp)
 
   Vec<> c(rows);
 
-  GNU_gama::IntegerList<> tmplist(rows);        
-  GNU_gama::IntegerList<>::iterator m = tmplist.begin();
+  IntegerList<> tmplist(rows);        
+  IntegerList<>::iterator m = tmplist.begin();
 
   long floats=0;
   for (long nonz, n, k, i=1; i<=rows; i++)
@@ -228,7 +228,7 @@ void AdjInputData::read_gama_local_old_format(std::istream& inp)
     }
 
   delete A;
-  A = new GNU_gama::SparseMatrix<>(floats, rows, cols);
+  A = new SparseMatrix<>(floats, rows, cols);
 
   m = tmplist.begin();
   for (long k=0, r=1; r<=rows; r++)
@@ -239,7 +239,7 @@ void AdjInputData::read_gama_local_old_format(std::istream& inp)
     }
 
   delete pcov;
-  pcov = new GNU_gama::BlockDiagonal<>(1, rows);
+  pcov = new BlockDiagonal<>(1, rows);
   pcov->add_block(rows, 0, c.begin());
 }
 
@@ -278,10 +278,10 @@ void Adj::init_least_squares()
   switch (algorithm_) 
     {
     case svd: 
-      least_squares = new GaMaLib::OLSsvd<double, Exception::matvec>;
+      least_squares = new AdjSVD<double, Exception::matvec>;
       break;
     case gso: 
-      least_squares = new GaMaLib::OLSgso<double, Exception::matvec>;
+      least_squares = new AdjGSO<double, Exception::matvec>;
       break;
     default:
       throw Exception::adjustment("### unknown algorithm");
@@ -303,10 +303,10 @@ void Adj::init_least_squares()
     {
       dim   = data->pcov->dim(b);
       width = data->pcov->width(b);
-      Cov<> C(dim, width);
+      CovMat<> C(dim, width);
 
       const double *p = data->pcov->begin(b), *e = data->pcov->end(b);
-      Cov<>::iterator c = C.begin();
+      CovMat<>::iterator c = C.begin();
       while (p != e) *c++ = *p++;
       cholesky(C);
 
@@ -363,7 +363,7 @@ Vec<> Adj::x()
  * in LocalNetwork and shall be moved to a single class
  * ###################################################################### */
 
-void Adj::cholesky(Cov<>& chol)
+void Adj::cholesky(CovMat<>& chol)
 {
   chol.cholDec();
 
@@ -382,7 +382,7 @@ void Adj::cholesky(Cov<>& chol)
     }
 }
 
-void Adj::forwardSubstitution(const Cov<>& chol, Vec<>& v)
+void Adj::forwardSubstitution(const CovMat<>& chol, Vec<>& v)
 {
   using namespace std;
   const std::size_t N = chol.rows();
