@@ -1,6 +1,6 @@
 /*  
     Geodesy and Mapping C++ Library (GNU GaMa / GaMaLib)
-    Copyright (C) 2002  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 2002  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU GaMa / GaMaLib C++ Library.
     
@@ -16,19 +16,19 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: adj.h,v 1.2 2005/03/27 17:43:26 cepek Exp $
+ *  $Id: adj.h,v 1.8 2005/06/04 21:02:04 cepek Exp $
  */
 
-#include <gnu_gama/matvec.h>
+#include <matvec/covmat.h>
 #include <gnu_gama/sparse/smatrix.h>
 #include <gnu_gama/sparse/sbdiagonal.h>
 #include <gnu_gama/sparse/intlist.h>
-#include <gamalib/ls/olssvd.h>
-#include <gamalib/ls/olsgso.h>
+#include <gnu_gama/adj/adj_svd.h>
+#include <gnu_gama/adj/adj_gso.h>
 
 #include <iostream>
 
@@ -61,7 +61,7 @@ namespace GNU_gama {
   private:
     
     const AdjInputData *data;
-    GaMaLib::BaseOLS<double, Exception::matvec> *least_squares;
+    AdjBase<double, Exception::matvec> *least_squares;
 
     bool      solved;
     algorithm algorithm_;
@@ -72,8 +72,8 @@ namespace GNU_gama {
   
     void init(const AdjInputData*);
     void init_least_squares();
-    void cholesky(Cov<>& chol);                            // move it away!   
-    void forwardSubstitution(const Cov<>& chol, Vec<>& v); // move it away!
+    void cholesky(CovMat<>& chol);                            // move it away!
+    void forwardSubstitution(const CovMat<>& chol, Vec<>& v); // move it away!
 
   };
   
@@ -87,10 +87,10 @@ namespace GNU_gama {
     void write_xml(std::ostream&) const;
     void read_xml(std::istream&);
 
-    const GNU_gama::SparseMatrix <> * mat () const { return A;     }
-    const GNU_gama::BlockDiagonal<> * cov () const { return pcov;  }
-    const           Vec          <>   rhs () const { return prhs;  }
-    const GNU_gama::IntegerList  <> * minx() const { return pminx; } 
+    const SparseMatrix <> * mat () const { return A;     }
+    const BlockDiagonal<> * cov () const { return pcov;  }
+    const Vec          <>   rhs () const { return prhs;  }
+    const IntegerList  <> * minx() const { return pminx; } 
 
     void set_mat (SparseMatrix <> * p) { delete A;     A     = p; }
     void set_cov (BlockDiagonal<> * p) { delete pcov;  pcov  = p; }
@@ -115,7 +115,7 @@ namespace GNU_gama {
 
   };
   
-}  // namespace GaMaLib
+}  // namespace GNU_gama
 
 #endif
 
