@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: g3_model_distance.cpp,v 1.7 2004/03/26 22:34:26 cepek Exp $
+ *  $Id: g3_model_distance.cpp,v 1.9 2005/05/07 18:06:20 cepek Exp $
  */
 
 #include <gnu_gama/g3/g3_model.h>
@@ -41,12 +41,12 @@ bool Model::revision_visit(Distance* d)
 
   active_obs->push_back(d);
 
-  update_index(from->N_);
-  update_index(from->E_);
-  update_index(from->U_);
-  update_index(to  ->N_);
-  update_index(to  ->E_);
-  update_index(to  ->U_);
+  update_index(from->N);
+  update_index(from->E);
+  update_index(from->U);
+  update_index(to  ->N);
+  update_index(to  ->E);
+  update_index(to  ->U);
   
   dm_rows += d->dimension();            // design matrix
 
