@@ -16,17 +16,17 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: g3_observation.h,v 1.12 2005/03/27 17:43:26 cepek Exp $
+ *  $Id: g3_observation.h,v 1.14 2005/05/07 18:06:20 cepek Exp $
  */
 
 
+#include <matvec/covmat.h>
 #include <gnu_gama/model.h>
 #include <gnu_gama/g3/g3_point.h>
-#include <gnu_gama/matvec.h>
 
 
 #ifndef GNU_gama__g3_observation_h_gnugamag3obs_baseh___gnu_gama_g3obs
@@ -37,7 +37,7 @@ namespace GNU_gama {  namespace g3 {
 
 
   class Observation :
-    public GNU_gama::Observation<Cluster<Observation>, GNU_gama::Cov<> >
+    public GNU_gama::Observation<Cluster<Observation>, GNU_gama::CovMat<> >
   {
   };
 
