@@ -16,14 +16,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: g3_point.h,v 1.24 2004/03/24 19:27:07 cepek Exp $
+ *  $Id: g3_point.h,v 1.27 2005/05/07 18:06:20 cepek Exp $
  */
 
-#include <gamalib/pointid.h>
+#include <string>
 #include <gnu_gama/g3/g3_parameter.h>
 
 #ifndef GNU_gama__g3_point_h_gnugamag3pointh___gnu_gama_g3point
@@ -37,16 +37,19 @@ namespace GNU_gama {  namespace g3 {
   class Point : public ParXML {
   public:
   
-    typedef GaMaLib::PointID Name;
-    typedef Model            Common;
+    typedef std::string   Name;
+    typedef Model         Common;
 
     Name    name;
     Common* common; 
 
-    const Parameter& N;
-    const Parameter& E;
-    const Parameter& U;
-    const Parameter& height;
+    Parameter N;
+    Parameter E;
+    Parameter U;
+    Parameter height;
+    Parameter geoid;
+    Parameter dB;
+    Parameter dL;
 
     const Parameter& B;
     const Parameter& L;
@@ -125,7 +128,6 @@ namespace GNU_gama {  namespace g3 {
     };
 
     friend class Model;
-    Parameter  N_, E_, U_, height_;
     Parameter  B_, L_, H_, X_, Y_, Z_;
 
     void point_copy(const Point&);
