@@ -16,18 +16,18 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: model.h,v 1.16 2004/06/20 20:54:51 cepek Exp $
+ *  $Id: model.h,v 1.18 2005/05/07 18:06:20 cepek Exp $
  */
 
 #ifndef GNU_gama__mathematical_model_h_gnugamamodel___gnu_gama_gmodel___h
 #define GNU_gama__mathematical_model_h_gnugamamodel___gnu_gama_gmodel___h
 
 #include <gnu_gama/obsdata.h>
-#include <gnu_gama/matvec.h>
+
 
 namespace GNU_gama {
 
