@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: obsdata.h,v 1.23 2004/09/01 11:59:45 cepek Exp $
+ *  $Id: obsdata.h,v 1.25 2005/05/07 18:06:20 cepek Exp $
  */
 
 
@@ -344,7 +344,7 @@ namespace GNU_gama {
       typedef std::size_t Index;
       // const Index M      = covariance_matrix.rows();
       const Index N      = activeDim();
-      const Index i_size = observation_list.size();
+      // const Index i_size = observation_list.size();
       Index active_band  = covariance_matrix.bandWidth();
 
       if (N)
