@@ -16,11 +16,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 /*
- *  $Id: version.cpp,v 1.56 2005/03/27 17:43:26 cepek Exp $
+ *  $Id: version.cpp,v 1.69 2005/06/13 14:43:39 cepek Exp $
  */
 
 
@@ -28,7 +28,7 @@
 
 namespace GNU_gama {
 
-const char* GNU_gama_version  = "1.7.12";
+const char* GNU_gama_version  = "1.7.13";
 
 const char* GNU_gama_compiler =
               #if   defined (__GNUC__)
@@ -62,6 +62,33 @@ const char* GNU_gama_compiler =
 
 =============================================================================
 
+1.7.13 2005-06-13
+
+    - added Cholesky decomposition as another adjustement algorithm
+      (template class AdjCholDec)
+
+    - removed unused method AdjBase<>::trwr()
+
+    - FSF's new address
+
+      find . -type f -exec sed -ie 's/59 Temple Place, Suite 330/51 Franklin
+      Street, Fifth Floor/;s/02111-1307/02110-1301/;' {} ';'
+
+    - three classes BaseOLS, OLSsvd and OLSgso (namespace GaMaLib,
+      directory gamalib/ls) renamed to AdjBase, AdjSVD and AdjGSO and
+      placed into the namespace GNU_gama (directory gnu_gama/adj).
+
+      From now there is no function, nor class, defined in the old
+      namespace GaMaLib referenced from the namespace GNU_gama.
+
+      Rather obsolete namespace GaMaLib is kept for the backward
+      compatibility and is mainly dedicated to the command line
+      program gama-local. 
+
+    - matrix/vector template library moved to the directory 'matvec'
+     
+
+
 1.7.12 2005-03-27
 
     - MatVec templete library moved to namespace GNU_gama
@@ -79,9 +106,9 @@ const char* GNU_gama_compiler =
 
     - a bug in the second GSO constructor
 
-        <  *  $Id: version.cpp,v 1.56 2005/03/27 17:43:26 cepek Exp $
+        <  *  $Id: version.cpp,v 1.69 2005/06/13 14:43:39 cepek Exp $
         ---
-        >  *  $Id: version.cpp,v 1.56 2005/03/27 17:43:26 cepek Exp $
+        >  *  $Id: version.cpp,v 1.69 2005/06/13 14:43:39 cepek Exp $
         80,83c80
         <   GSO(Mat<Float, Exc>& a, Index m, Index n)
         <     : pA(0), M(0), N(0), sc(true), tol_(0),
